Core Concepts
-------------

Example with the core concepts and usage of this library.

.. literalinclude:: ../examples/python/ping_pong.py
    :caption: examples/python/ping_pong.py
    :linenos:

Alarm
-----

.. literalInclude:: ../examples/python/alarm.py
    :caption: examples/python/alarm.py
    :linenos:

Traffic Lights
--------------

.. literalInclude:: ../examples/python/traffic_lights.py
    :caption: examples/python/traffic_lights.py
    :linenos:

Stand-alone Observers
---------------------

.. literalInclude:: ../examples/python/echo_observer.py
    :caption: examples/python/echo_observer.py
    :linenos:
